==> tiki-9.7.tar.bz2: tiki-9.7/lang/tv/language.php <==
<?php


$lang = array(
"Czech" => "Gana Czech",
"Danish" => "Gana Danish",
"German" => "Gana Tiamani",
"English" => "Gana Palagi",
"Spanish" => "Gana Spanish",
"Greek" => "Gana Greek",
"French" => "Gana Falani",
"Italian" => "Gana Itali",
"Japanese" => "Gana Tiapani",
"Dutch" => "Gana Dutch",
"Norwegian" => "Gana Nouei",
"Polish" => "Gana Polish",
"Russian" => "Gana Lusia",
"Swedish" => "Gana Swedish",
"You must supply all the information, including title and year." => "E tau o tuku mai ne koe a fakamatalaga katoa fakatasi mote ulutala mote tausaga.",
"You do not have permission to use this feature" => "Taliaga se avatu ke \nfakaoga ne koe te feature tenei",
"Sunday" => "Asosa",
"Monday" => "Aso Gafua",
"Tuesday" => "Aso Lua",
"Wednesday" => "Aso Tolu",
"Thursday" => "Aso Faa",
"Friday" => "Aso Lima",
"Saturday" => "Aso Ono",
"Image Gallery" => "Gallery Ata",
"Permission denied" => "Se avatu taliaga",
"Could not upload the file" => "Se maua o upload te faila tenei",
"This feature is disabled" => "Te mae nei ko oti ne se fakagalue",
"Newest first" => "Meafoou ke mua",
"Oldest first" => "Meamua ke mua",
"1" => "Strict allows page names with only letters, numbers, underscore, dash, period and\nsemicolon (dash, period and semicolon not allowed at the beginning and the end).",
"2" => "Displayed now for all eligible users even with personal assigned modules",
"Contact Us" => "Fesokotaki kia matou",
"full path to mapfiles" => "te auala katoatoa ki mapfiles",
"Password is required" => "Manakogina te password",
"User already exists" => "Tino tenei ko leva ne iai",
"The passwords don't match" => "Se pau te password",
"You are not logged in" => "Koe seki log in",
"You do not have permission to view this section" => "Taliaga se avatu ke pula koe ki te\nkogaa koga tenei",
"Unknown language" => "Gana Fakatea",
"Password must contain both letters and numbers" => "Password e tau o aofia a mataimanu \nmo napa",
"Select" => "Fili tenei",
"File not found" => "File se maua",
"No pages found for title search" => "Seai ne itulau e maua ite salaga ote ulutala nei",
"One page found for title search" => "E tasi te itulau e maua ite ulutala tenei",
"pages found for title search" => "itulau e maua ite ulutala tenei",
"No more messages" => "Ko seai aka ne fekau",
"Create" => "Faite",
"No categories defined" => "Seai ne categories ko oti ne",
"New Reply" => "Tali foou",
"you have requested to download the layer:" => "koe ne manako ke download te layer:",
"Here are the files to download, do not forget to rename them:" => "Konei a files ke download sa puli o toe fakaigoa:",
"Stop Monitoring this Map" => "Ko lava te monitor te map",
"You can view this map in your browser using" => "E mafai o matea ne koe te mape tenei i luga i tau browser ma fakaoga",
"click on the map to zoom or pan, do not drag" => "Toko i luga ite mape ke zoom, pan, sa drag",
"of" => "o",
"Create Directory:" => "Faite Directory:",
"Made with" => "Faite ite",
"Maps" => "A mape",
"Create/Edit External Wiki" => "Faite/fakamafuli External Wiki",
"Originating e-mail address for mails from this forum" => "Te e-mail address address e fakaasi\ni luga i meli e kave mai te forum tenei",
"Users can subscribe/unsubscribe to this list" => "Tino fakaoga e mafai o subscribe/unsubscribe\nkite list tenei",
"Users can subscribe any email address" => "Tino fakaoga e mafai osubscribe sose email address",
"Validate email addresses" => "Fakamaoni te email addresses",
"show publish date" => "Fakaasi te aso ne faite iei",
"Trash" => "Kaiga",
"View Results" => "Onoono ki Results",
"remove" => "tapale",
"Show All" => "Fakaasi katoa",
"Message sent to" => "Fekau ne ave kia",
"Group already exists" => "Group tenei e isi",
"User doesn't exist" => "Te tino tenei e seai",
"You do not have permission to view this page." => "Taliaga se avatu ke \nonoono koe kite itulau tenei",
"No records were found. Check the file please!" => "Seai ne records ne maua. Toe onoono kite file fakamolemole!",
"User login is required" => "Tino fakaoga e mnakogina ke log in",
"Email is required" => "Manakogina te e-mail",
"You do not have permission to edit this post" => "Se maua sou taliaga, e se mafai o fai ne fakamafuliga kite post tenei",
"No blogId specified" => "Seai sau blogId ne fakailoa",
"You do not have permission to remove images from this gallery" => "Taliaga se avatu ke  tapale ne koe a ata i loto i te gallery",
"You do not have permission to rotate images in this gallery" => "Taliaga se avatu ke \nfakamio ne koe a ata i loto i te gallery",
"You do not have permission to move images from this gallery" => "Taliaga se avatu ke \nfakagasue ne koe ata mai te gallery tenei",
"You do not have permission to view the calendar" => "Taliaga se avatu ke onoono koe \nki te Kalena",
"You can not use the same password again" => "E se mafai o toe fakaoga te password mua",
"Invalid old password" => "E se tau password mua",
"Must enter a name to add a site" => "Faulu se igoa ke faopoopo se site",
"Must enter a url to add a site" => "Faulu se url ke faopoopo se site",
"Must select a category" => "Tau o fili se vaega (category)",
"Banner not found" => "Banner e se maua",
"No galleryId specified" => "Seai sau galleryId ne fakailoa",
"No forumId specified" => "Seai sau forumId ne fakailoa",
"mapfile name incorrect" => "Te igoa ote mapfile e se",
"This mapfile already exists" => "Te mapfile tenei ko leva ne isi",
"The Directory is not empty" => "Te Directory nei koi isi ne mea i loto",
"TOP" => "KI LUGA",
"You are not permitted to remove someone else's post!" => "E se talia ke fakaseai ne koe a te post ate suaa tino!",
"You do not have permissions to view the maps" => "Seai se taliaga ke onoono koe ki mape",
);

==> tiki-19.1.tar.bz2: tiki-19.1/lang/tv/language.php <==
<?php



$lang = array(
"Czech" => "Gana Czech",
"Danish" => "Gana Danish",
"German" => "Gana Tiamani",
"English" => "Gana Palagi",
"Spanish" => "Gana Spanish",
"Greek" => "Gana Greek",
"French" => "Gana Falani",
"Italian" => "Gana Itali",
"Japanese" => "Gana Tiapani",
"Dutch" => "Gana Dutch",
"Norwegian" => "Gana Nouei",
"Polish" => "Gana Polish",
"Russian" => "Gana Lusia",
"Swedish" => "Gana Swedish",
"You must supply all the information, including title and year." => "E tau o tuku mai ne koe a fakamatalaga katoa fakatasi mote ulutala mote tausaga.",
"Sunday" => "Asosa",
"Monday" => "Aso Gafua",
"Tuesday" => "Aso Lua",
"Wednesday" => "Aso Tolu",
"Thursday" => "Aso Faa",
"Friday" => "Aso Lima",
"Saturday" => "Aso Ono",
"Image Gallery" => "Gallery Ata",
"Permission denied" => "Se avatu taliaga",
"Group already exists" => "Group tenei e isi",
"Create" => "Faite",
"File not found" => "File se maua",
"Unknown language" => "Gana Fakatea",
"Newest first" => "Meafoou ke mua",
"Oldest first" => "Meamua ke mua",
"2" => "Displayed now for all eligible users even with personal assigned modules",
"Password is required" => "Manakogina te password",
"User already exists" => "Tino tenei ko leva ne iai",
"The passwords don't match" => "Se pau te password",
"You do not have the permission that is needed to use this feature" => "Taliaga se avatu ke \nfakaoga ne koe te feature tenei",
"You are not logged in" => "Koe seki log in",
"You do not have permission to view this section" => "Taliaga se avatu ke pula koe ki te\nkogaa koga tenei",
"Password must contain both letters and numbers" => "Password e tau o aofia a mataimanu \nmo napa",
"Select" => "Fili tenei",
"This feature is disabled" => "Te mae nei ko oti ne se fakagalue",
"No pages found for title search" => "Seai ne itulau e maua ite salaga ote ulutala nei",
"One page found for title search" => "E tasi te itulau e maua ite ulutala tenei",
"pages found for title search" => "itulau e maua ite ulutala tenei",
"No more messages" => "Ko seai aka ne fekau",
"No categories defined" => "Seai ne categories ko oti ne",
"New Reply" => "Tali foou",
"Create/Edit External Wiki" => "Faite/fakamafuli External Wiki",
"Originating email address for emails from this forum" => "Te e-mail address address e fakaasi\ni luga i meli e kave mai te forum tenei",
"Users can subscribe/unsubscribe to this list" => "Tino fakaoga e mafai o subscribe/unsubscribe\nkite list tenei",
"Users can subscribe any email address" => "Tino fakaoga e mafai osubscribe sose email address",
"Validate email addresses" => "Fakamaoni te email addresses",
"of" => "o",
"Contact Us" => "Fesokotaki kia matou",
"View Results" => "Onoono ki Results",
"remove" => "tapale",
"Trash" => "Kaiga",
"Show All" => "Fakaasi katoa",
"Message sent to" => "Fekau ne ave kia",
"Maps" => "A mape",
"You do not have permission to view this page." => "Taliaga se avatu ke \nonoono koe kite itulau tenei",
"User doesn't exist" => "Te tino tenei e seai",
"No records were found. Check the file please!" => "Seai ne records ne maua. Toe onoono kite file fakamolemole!",
"User login is required" => "Tino fakaoga e mnakogina ke log in",
"Email is required" => "Manakogina te e-mail",
"You do not have permission to edit this post" => "Se maua sou taliaga, e se mafai o fai ne fakamafuliga kite post tenei",
"No blogId specified" => "Seai sau blogId ne fakailoa",
"You do not have permission to remove images from this gallery" => "Taliaga se avatu ke  tapale ne koe a ata i loto i te gallery",
"You do not have permission to rotate images in this gallery" => "Taliaga se avatu ke \nfakamio ne koe a ata i loto i te gallery",
"You do not have permission to move images from this gallery" => "Taliaga se avatu ke \nfakagasue ne koe ata mai te gallery tenei",
"You do not have permission to view the calendar" => "Taliaga se avatu ke onoono koe \nki te Kalena",
"You can not use the same password again" => "E se mafai o toe fakaoga te password mua",
"Invalid old password" => "E se tau password mua",
"Must enter a name to add a site" => "Faulu se igoa ke faopoopo se site",
"Must enter a url to add a site" => "Faulu se url ke faopoopo se site",
"Must select a category" => "Tau o fili se vaega (category)",
"Banner not found" => "Banner e se maua",
"No gallery ID specified" => "Seai sau galleryId ne fakailoa",
"No forumId specified" => "Seai sau forumId ne fakailoa",
"TOP" => "KI LUGA",
"You do not have permission to remove someone else's post!" => "E se talia ke fakaseai ne koe a te post ate suaa tino!",
);
